<?php
/**
 * Plugin Name: Bexio Connector by Helvy
 * Version: 0.2.2
 * Description: Save time by synchronizing your shop with bexio!
 * Author: Helvy Sàrl
 * Author URI: https://helvy.ch
 * Text Domain: bexio-connector-by-helvy
 * Domain Path: /languages
 * Requires at least: 5.9
 * Tested up to: 6.1
 * Requires PHP: 7.3
 * Requires Plugins: woocommerce
 * 
 * License: GNU General Public License v3.0
 * License URI: http://www.gnu.org/licenses/gpl-3.0.html
 *
 * @package extension
 */

defined( 'ABSPATH' ) || exit;

if ( ! defined( 'MAIN_PLUGIN_FILE' ) ) {
	define( 'MAIN_PLUGIN_FILE', __FILE__ );
}

require_once plugin_dir_path( __FILE__ ) . '/vendor/autoload_packages.php';
require_once plugin_dir_path( __FILE__ ) . '/config.php';
require_once plugin_dir_path( __FILE__ ) . '/plugin-update-checker/plugin-update-checker.php';
use YahnisElsts\PluginUpdateChecker\v5\PucFactory;
use BexioConnectorByHelvy\Admin\Setup;

// phpcs:disable WordPress.Files.FileName

/**
 * WooCommerce fallback notice.
 *
 * @since 0.1.0
 */
function bexio_connector_by_helvy_missing_wc_notice() {
	/* translators: %s WC download URL link. */
	echo '<div class="error"><p><strong>' . sprintf( esc_html__( 'Bexio Connector by Helvy requires WooCommerce to be installed and active. You can download %s here.', 'bexio_connector_by_helvy' ), '<a href="https://woo.com/" target="_blank">WooCommerce</a>' ) . '</strong></p></div>';
}

$crons = new BexioConnectorByHelvy\Crons();
register_activation_hook(__FILE__, array($crons, 'register_batch_products_sync_event'));
register_deactivation_hook(__FILE__, array($crons, 'clear_batch_products_sync_event'));

register_activation_hook( __FILE__, 'bexio_connector_by_helvy_activate' );

/**
 * Activation hook.
 *
 * @since 0.1.0
 */
function bexio_connector_by_helvy_activate() {
	if ( ! class_exists( 'WooCommerce' ) ) {
		add_action( 'admin_notices', 'bexio_connector_by_helvy_missing_wc_notice' );
		return;
	}
}

if ( ! class_exists( 'bexio_connector_by_helvy' ) ) :
	/**
	 * The bexio_connector_by_helvy class.
	 */
	class bexio_connector_by_helvy {
		/**
		 * This class instance.
		 *
		 * @var \bexio_connector_by_helvy single instance of this class.
		 */
		private static $instance;

		/**
		 * Constructor.
		 */
		public function __construct() {
			$this->includes();
		}

		private function includes() {
			if (is_admin()) {
				new BexioConnectorByHelvy\AdminMenu();
				new BexioConnectorByHelvy\AdminPanelAssets();
				PucFactory::buildUpdateChecker(
					BexioConnectorByHelvy\API::getApiDomain() . '/public/plugin-details.json',
					__FILE__,
					'bexio-connector-by-helvy'
				);
			}
			new BexioConnectorByHelvy\AdminAPIAuth();
			new BexioConnectorByHelvy\AdminAPISettings();
			new BexioConnectorByHelvy\AdminAPISynchronization();
			new BexioConnectorByHelvy\WooCommerceWebhooks();
		}

        /**
         * Add a new integration to WooCommerce.
         */
        public function add_integration( $integrations ) {
            $integrations[] = 'Bexio_Connector_Integration';
            return $integrations;
        }

		/**
		 * Cloning is forbidden.
		 */
		public function __clone() {
			wc_doing_it_wrong( __FUNCTION__, __( 'Cloning is forbidden.', 'bexio_connector_by_helvy' ), BEXIO_CONNECTOR_BY_HELVY_VERSION );
		}

		/**
		 * Unserializing instances of this class is forbidden.
		 */
		public function __wakeup() {
			wc_doing_it_wrong( __FUNCTION__, __( 'Unserializing instances of this class is forbidden.', 'bexio_connector_by_helvy' ), BEXIO_CONNECTOR_BY_HELVY_VERSION );
		}

		/**
		 * Gets the main instance.
		 *
		 * Ensures only one instance can be loaded.
		 *
		 * @return \bexio_connector_by_helvy
		 */
		public static function instance() {

			if ( null === self::$instance ) {
				self::$instance = new self();
			}

			return self::$instance;
		}
	}
endif;

add_action( 'plugins_loaded', 'bexio_connector_by_helvy_init', 10 );

/**
 * Initialize the plugin.
 *
 * @since 0.1.0
 */
function bexio_connector_by_helvy_init() {
	load_plugin_textdomain( 'bexio-connector-by-helvy', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
	if ( ! class_exists( 'WooCommerce' ) ) {
		add_action( 'admin_notices', 'bexio_connector_by_helvy_missing_wc_notice' );
		return;
	}

	bexio_connector_by_helvy::instance();
}

add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'add_custom_plugin_link');

/**
 * Add a custom links to the plugin actions
 *
 * @param array $links Existing plugin action links
 * @return array Modified plugin action links
 */
function add_custom_plugin_link($links)
{
	$settings_link = '<a href="admin.php?page=bexio-connector-by-helvy&section=settings">'.__('Settings').'</a>';
	array_unshift($links, $settings_link);

	$view_link = '<a href="admin.php?page=bexio-connector-by-helvy">'.__('View').'</a>';
	array_unshift($links, $view_link);

	return $links;
}